/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIN DE LA EDUCACIN
/*             UNIDAD DE EVALUACIN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIN GENERAL DE MEDICIN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIN DE TRATAMIENTO DE DATOS
/*
/*_____________________________________________________________________________
/*
/*            EXAMENES DE LA CALIDAD Y EL LOGRO EDUCATIVOS (Excale)
/*                     TERCER GRADO DE PRIMARIA (Excale 03)
/*
/*                      **** FORMACIN CVICA Y TICA ****
/*
/*                     Ciclo escolar evaluado: 2013 - 2014
/*_____________________________________________________________________________
/*
/*
/*            SINTAXIS PARA CONSTRUIR LA BASE DE DATOS DE ALUMNOS DE
/*                   FORMACIN CVICA Y TICA EN FORMATO SAS
/*_____________________________________________________________________________
/*
/*  El programa convierte al archivo Excale03_2014_Alum_FCE.txt, el cual est en
/*  formato ASCII, en una base de datos en formato SAS. El programa realiza las
/*  siguientes tareas:
/*   - Declara formatos para algunas variables
/*   - Lee las variables del archivo en formato ASCII
/*   - Declara los valores considerados en el anlisis como perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para construir la base de datos (tabla de datos) es necesario:
/*      1) Crear una carpeta de trabajo y colocar en ella al archivo Excale03_2014_Alum_FCE.txt
/*         as como el archivo Excale03_2014_Alum_FCE.SAS (este archivo) los cules se pueden
/*         descargar del sitio web del INEE (www.inee.edu.mx).
/*      2) Modificar la primera y segunda lnea de los comandos de este archivo
/*         (libname y filename) para actualizar el nombre de la librera y el archivo
/*         de trabajo.
/*      3) Ejecutar el programa del archivo.
/*
/*  Al finalizar, se deber contar con la base de datos (tabla de datos) Excale03_2014_Alum_FCE.sas7bdat
/*
/*  Posteriormente, cuando se desee utilizar nuevamente la base Excale03_2014_Alum_FCE.sas7bdat,
/*  se deber ejecutar primero el procedimiento FORMAT ("proc FORMAT") de este programa para que
/*  SAS cargue los formatos necesarios para abrir la base.
/*
/* CONTACTO:
/*
/*      Para mayor informacin o aclaracin de dudas favor de contactar a la
/*      Direccin de Tratamiento de Datos
/*      Correo electrnico: excale.analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San Jos Insurgentes
/*                 Del. Benito Jurez. Mxico. D.F.
/*
/* FECHA DE LIBERACIN: 01 DE SEPTIEMBRE 2015
/*
/*  ****************************************************************************/

LIBNAME  INEE  "C:\***\";
FILENAME alum  "C:\***\Excale03_2014_Alum_FCE.TXT";

PROC FORMAT;
     VALUE id_entF     1       = "Aguascalientes"
                       2       = "Baja California"
                       3       = "Baja California Sur"
                       4       = "Campeche"
                       5       = "Coahuila"
                       6       = "Colima"
                       7       = "Chiapas"
                       8       = "Chihuahua"
                       9       = "Distrito Federal"
                       10      = "Durango"
                       11      = "Guanajuato"
                       12      = "Guerrero"
                       13      = "Hidalgo"
                       14      = "Jalisco"
                       15      = "Mxico"
                       16      = "Michoacn"
                       17      = "Morelos"
                       18      = "Nayarit"
                       19      = "Nuevo Len"
                       20      = "Oaxaca"
                       21      = "Puebla"
                       22      = "Quertaro"
                       23      = "Quintana Roo"
                       24      = "San Luis Potos"
                       25      = "Sinaloa"
                       26      = "Sonora"
                       27      = "Tabasco"
                       28      = "Tamaulipas"
                       29      = "Tlaxcala"
                       30      = "Veracruz"
                       31      = "Yucatn"
                       32      = "Zacatecas";
     VALUE id_modF     1       = "Urbana Pblica"
                       2       = "Rural Pblica"
                       3       = "Educacin Indgena"
                       4       = "Curso Comunitario"
                       5       = "Privada"
                       6       = "General"
                       7       = "Tcnica"
                       8       = "Telesecundaria"
                       9       = "Privada";
     VALUE $modF       "UP"    = "Urbano Pblico"
                       "RP"    = "Rural Pblico"
                       "EI"    = "Educacin Indgena"
                       "CC"    = "Cursos Comunitarios"
                       "UPV"   = "Privada"
                       "GRAL"  = "General"
                       "TEC"   = "Tcnica"
                       "TV"    = "Telesecundaria"
                       "PRIV"  = "Privada";
     VALUE $entestF    "999"   = "Respuesta omitida";
     VALUE sexoF       1       = "Hombre"
                       2       = "Mujer"
                       8       = "Respuesta mltiple"
                       9       = "Respuesta omitida";
     VALUE edad_acF    98      = "Respuesta mltiple"
                       99      = "Respuesta omitida";
     VALUE mes_nacF    1       = "Enero"
                       2       = "Febrero"
                       3       = "Marzo"
                       4       = "Abril"
                       5       = "Mayo"
                       6       = "Junio"
                       7       = "Julio"
                       8       = "Agosto"
                       9       = "Septiembre"
                       10      = "Octubre"
                       11      = "Noviembre"
                       12      = "Diciembre"
                       98      = "Respuesta mltiple"
                       99      = "Respuesta omitida";
     VALUE edadF       99      = "Respuesta omitida";
     VALUE edadCF      1       = "8 aos o menos"
                       2       = "9 aos"
                       3       = "10 aos"
                       4       = "11 aos o ms"
                       9       = "Respuesta omitida";
     VALUE edadNF      1       = "Edad normativa"
                       2       = "Extra-edad"
                       9       = "Respuesta omitida";
     VALUE edadAF      0       = "Sin edad anticipada"
                       1       = "Edad anticipada"
                       9       = "Respuesta omitida";
     VALUE edadEF      0       = "Sin extra edad severa"
                       1       = "Extra edad severa"
                       9       = "Respuesta omitida";
     VALUE docenF      99999   = "Respuesta omitida";
     VALUE reactF      0       = "Fallo"
                       1       = "Acierto"
                       5       = "Reactivo no alcanzado (se considera como no administrado)"
                       6       = "Reactivo no administrado por error de impresin"
                       7       = "Reactivo no administrado (No se incluy en su cuadernillo de examen)";
     VALUE nvlF        1       = "Por debajo del nivel bsico"
                       2       = "Bsico"
                       3       = "Medio"
                       4       = "Avanzado";
     VALUE nvblF       0       = "Por debajo del nivel bsico"
                       1       = "Al menos el nivel bsico";
     VALUE nvmlF       0       = "Por debajo del nivel medio"
                       1       = "Al menos el nivel medio";
RUN;



DATA INEE.Excale03_2014_Alum_FCE;
   LENGTH
       NACIONAL     3
       ESCUELA      4
       ID_ENT       3
       NOM_ENT      $19
       ID_MOD       3
       MOD          $4
       ESTRATO      $7
       ENTEST       $6
       ALUMNO       5
       ID_INSTR     $15
       SEXO         3
       EDAD_AC      3
       MES_NAC      3
       EDAD         8
       EDAD_ACC     3
       EDAD_N       3
       EDAD_ANT     3
       EDAD_EES     3
       W_ALU        8
       DOCENTE      5
       PCA_01       3
       PCA_02       3
       PCA_03       3
       PCA_04       3
       PCA_05       3
       PCA_06       3
       PCA_07       3
       PCA_08       3
       PCA_09       3
       PCA_10       3
       PCA_11       3
       PCA_12       3
       PCA_13       3
       PCA_14       3
       PCA_15       3
       PCA_16       3
       PCA_17       3
       PCB_01       3
       PCB_02       3
       PCB_03       3
       PCB_04       3
       PCB_05       3
       PCB_06       3
       PCB_07       3
       PCB_08       3
       PCB_09       3
       PCB_10       3
       PCB_11       3
       PCB_12       3
       PCB_13       3
       PCB_14       3
       PCB_15       3
       PCB_16       3
       PCB_17       3
       PCC_01       3
       PCC_02       3
       PCC_03       3
       PCC_04       3
       PCC_05       3
       PCC_06       3
       PCC_07       3
       PCC_08       3
       PCC_09       3
       PCC_10       3
       PCC_11       3
       PCC_12       3
       PCC_13       3
       PCC_14       3
       PCC_15       3
       PCC_16       3
       PCC_17       3
       PCD_01       3
       PCD_02       3
       PCD_03       3
       PCD_04       3
       PCD_05       3
       PCD_06       3
       PCD_07       3
       PCD_08       3
       PCD_09       3
       PCD_10       3
       PCD_11       3
       PCD_12       3
       PCD_13       3
       PCD_14       3
       PCD_15       3
       PCD_16       3
       PCD_17       3
       PCD_18       3
       PCE_01       3
       PCE_02       3
       PCE_03       3
       PCE_04       3
       PCE_05       3
       PCE_06       3
       PCE_07       3
       PCE_08       3
       PCE_10       3
       PCE_11       3
       PCE_12       3
       PCE_13       3
       PCE_14       3
       PCE_15       3
       PCE_16       3
       PCE_17       3
       PCF_01       3
       PCF_02       3
       PCF_03       3
       PCF_04       3
       PCF_05       3
       PCF_06       3
       PCF_07       3
       PCF_08       3
       PCF_10       3
       PCF_11       3
       PCF_12       3
       PCF_13       3
       PCF_14       3
       PCF_15       3
       PCF_16       3
       PCF_17       3
       PV1FCE       8
       PV2FCE       8
       PV3FCE       8
       PV4FCE       8
       PV5FCE       8
       FCENVL1      3
       FCENVL2      3
       FCENVL3      3
       FCENVL4      3
       FCENVL5      3
       FCENVBL1     3
       FCENVBL2     3
       FCENVBL3     3
       FCENVBL4     3
       FCENVBL5     3
       FCENVML1     3
       FCENVML2     3
       FCENVML3     3
       FCENVML4     3
       FCENVML5     3
       WVARSTRR     3
       W_FSTR1      8
       W_FSTR2      8
       W_FSTR3      8
       W_FSTR4      8
       W_FSTR5      8
       W_FSTR6      8
       W_FSTR7      8
       W_FSTR8      8
       W_FSTR9      8
       W_FSTR10     8
       W_FSTR11     8
       W_FSTR12     8
       W_FSTR13     8
       W_FSTR14     8
       W_FSTR15     8
       W_FSTR16     8
       W_FSTR17     8
       W_FSTR18     8
       W_FSTR19     8
       W_FSTR20     8
       W_FSTR21     8
       W_FSTR22     8
       W_FSTR23     8
       W_FSTR24     8
       W_FSTR25     8
       W_FSTR26     8
       W_FSTR27     8
       W_FSTR28     8
       W_FSTR29     8
       W_FSTR30     8
       W_FSTR31     8
       W_FSTR32     8
       W_FSTR33     8
       W_FSTR34     8
       W_FSTR35     8
       W_FSTR36     8
       W_FSTR37     8
       W_FSTR38     8
       W_FSTR39     8
       W_FSTR40     8
       W_FSTR41     8
       W_FSTR42     8
       W_FSTR43     8
       W_FSTR44     8
       W_FSTR45     8
       W_FSTR46     8
       W_FSTR47     8
       W_FSTR48     8
       W_FSTR49     8
       W_FSTR50     8
       W_FSTR51     8
       W_FSTR52     8
       W_FSTR53     8
       W_FSTR54     8
       W_FSTR55     8
       W_FSTR56     8
       W_FSTR57     8
       W_FSTR58     8
       W_FSTR59     8
       W_FSTR60     8
       W_FSTR61     8
       W_FSTR62     8
       W_FSTR63     8
       W_FSTR64     8
       W_FSTR65     8
       W_FSTR66     8
       W_FSTR67     8
       W_FSTR68     8
       W_FSTR69     8
       W_FSTR70     8
       W_FSTR71     8
       W_FSTR72     8
       W_FSTR73     8
       W_FSTR74     8
       W_FSTR75     8
       W_FSTR76     8
       W_FSTR77     8
       W_FSTR78     8
       W_FSTR79     8
       W_FSTR80     8
       W_FSTR81     8
       W_FSTR82     8
       W_FSTR83     8
       W_FSTR84     8
       W_FSTR85     8
       W_FSTR86     8
       W_FSTR87     8
       W_FSTR88     8
       W_FSTR89     8
       W_FSTR90     8
       W_FSTR91     8
       W_FSTR92     8
       W_FSTR93     8
       W_FSTR94     8
       W_FSTR95     8
       W_FSTR96     8
       W_FSTR97     8
       W_FSTR98     8
       W_FSTR99     8
       W_FSTR100    8
;



INFILE alum MISSOVER LINESIZE = 1361;
   INPUT
      NACIONAL       1 - 1
      ESCUELA        2 - 5
      ID_ENT         6 - 7
      NOM_ENT        8 - 27
      ID_MOD        28 - 28
      MOD           29 - 32
      ESTRATO       33 - 40
      ENTEST        41 - 46
      ALUMNO        47 - 51
      ID_INSTR      52 - 66
      SEXO          67 - 67
      EDAD_AC       68 - 69
      MES_NAC       70 - 71
      EDAD          72 - 82
      EDAD_ACC      83 - 83
      EDAD_N        84 - 84
      EDAD_ANT      85 - 85
      EDAD_EES      86 - 86
      W_ALU         87 - 97
      DOCENTE       98 - 102
      PCA_01       103 - 103
      PCA_02       104 - 104
      PCA_03       105 - 105
      PCA_04       106 - 106
      PCA_05       107 - 107
      PCA_06       108 - 108
      PCA_07       109 - 109
      PCA_08       110 - 110
      PCA_09       111 - 111
      PCA_10       112 - 112
      PCA_11       113 - 113
      PCA_12       114 - 114
      PCA_13       115 - 115
      PCA_14       116 - 116
      PCA_15       117 - 117
      PCA_16       118 - 118
      PCA_17       119 - 119
      PCB_01       120 - 120
      PCB_02       121 - 121
      PCB_03       122 - 122
      PCB_04       123 - 123
      PCB_05       124 - 124
      PCB_06       125 - 125
      PCB_07       126 - 126
      PCB_08       127 - 127
      PCB_09       128 - 128
      PCB_10       129 - 129
      PCB_11       130 - 130
      PCB_12       131 - 131
      PCB_13       132 - 132
      PCB_14       133 - 133
      PCB_15       134 - 134
      PCB_16       135 - 135
      PCB_17       136 - 136
      PCC_01       137 - 137
      PCC_02       138 - 138
      PCC_03       139 - 139
      PCC_04       140 - 140
      PCC_05       141 - 141
      PCC_06       142 - 142
      PCC_07       143 - 143
      PCC_08       144 - 144
      PCC_09       145 - 145
      PCC_10       146 - 146
      PCC_11       147 - 147
      PCC_12       148 - 148
      PCC_13       149 - 149
      PCC_14       150 - 150
      PCC_15       151 - 151
      PCC_16       152 - 152
      PCC_17       153 - 153
      PCD_01       154 - 154
      PCD_02       155 - 155
      PCD_03       156 - 156
      PCD_04       157 - 157
      PCD_05       158 - 158
      PCD_06       159 - 159
      PCD_07       160 - 160
      PCD_08       161 - 161
      PCD_09       162 - 162
      PCD_10       163 - 163
      PCD_11       164 - 164
      PCD_12       165 - 165
      PCD_13       166 - 166
      PCD_14       167 - 167
      PCD_15       168 - 168
      PCD_16       169 - 169
      PCD_17       170 - 170
      PCD_18       171 - 171
      PCE_01       172 - 172
      PCE_02       173 - 173
      PCE_03       174 - 174
      PCE_04       175 - 175
      PCE_05       176 - 176
      PCE_06       177 - 177
      PCE_07       178 - 178
      PCE_08       179 - 179
      PCE_10       180 - 180
      PCE_11       181 - 181
      PCE_12       182 - 182
      PCE_13       183 - 183
      PCE_14       184 - 184
      PCE_15       185 - 185
      PCE_16       186 - 186
      PCE_17       187 - 187
      PCF_01       188 - 188
      PCF_02       189 - 189
      PCF_03       190 - 190
      PCF_04       191 - 191
      PCF_05       192 - 192
      PCF_06       193 - 193
      PCF_07       194 - 194
      PCF_08       195 - 195
      PCF_10       196 - 196
      PCF_11       197 - 197
      PCF_12       198 - 198
      PCF_13       199 - 199
      PCF_14       200 - 200
      PCF_15       201 - 201
      PCF_16       202 - 202
      PCF_17       203 - 203
      PV1FCE       204 - 211
      PV2FCE       212 - 219
      PV3FCE       220 - 227
      PV4FCE       228 - 235
      PV5FCE       236 - 243
      FCENVL1      244 - 244
      FCENVL2      245 - 245
      FCENVL3      246 - 246
      FCENVL4      247 - 247
      FCENVL5      248 - 248
      FCENVBL1     249 - 249
      FCENVBL2     250 - 250
      FCENVBL3     251 - 251
      FCENVBL4     252 - 252
      FCENVBL5     253 - 253
      FCENVML1     254 - 254
      FCENVML2     255 - 255
      FCENVML3     256 - 256
      FCENVML4     257 - 257
      FCENVML5     258 - 258
      WVARSTRR     259 - 261
      W_FSTR1      262 - 272
      W_FSTR2      273 - 283
      W_FSTR3      284 - 294
      W_FSTR4      295 - 305
      W_FSTR5      306 - 316
      W_FSTR6      317 - 327
      W_FSTR7      328 - 338
      W_FSTR8      339 - 349
      W_FSTR9      350 - 360
      W_FSTR10     361 - 371
      W_FSTR11     372 - 382
      W_FSTR12     383 - 393
      W_FSTR13     394 - 404
      W_FSTR14     405 - 415
      W_FSTR15     416 - 426
      W_FSTR16     427 - 437
      W_FSTR17     438 - 448
      W_FSTR18     449 - 459
      W_FSTR19     460 - 470
      W_FSTR20     471 - 481
      W_FSTR21     482 - 492
      W_FSTR22     493 - 503
      W_FSTR23     504 - 514
      W_FSTR24     515 - 525
      W_FSTR25     526 - 536
      W_FSTR26     537 - 547
      W_FSTR27     548 - 558
      W_FSTR28     559 - 569
      W_FSTR29     570 - 580
      W_FSTR30     581 - 591
      W_FSTR31     592 - 602
      W_FSTR32     603 - 613
      W_FSTR33     614 - 624
      W_FSTR34     625 - 635
      W_FSTR35     636 - 646
      W_FSTR36     647 - 657
      W_FSTR37     658 - 668
      W_FSTR38     669 - 679
      W_FSTR39     680 - 690
      W_FSTR40     691 - 701
      W_FSTR41     702 - 712
      W_FSTR42     713 - 723
      W_FSTR43     724 - 734
      W_FSTR44     735 - 745
      W_FSTR45     746 - 756
      W_FSTR46     757 - 767
      W_FSTR47     768 - 778
      W_FSTR48     779 - 789
      W_FSTR49     790 - 800
      W_FSTR50     801 - 811
      W_FSTR51     812 - 822
      W_FSTR52     823 - 833
      W_FSTR53     834 - 844
      W_FSTR54     845 - 855
      W_FSTR55     856 - 866
      W_FSTR56     867 - 877
      W_FSTR57     878 - 888
      W_FSTR58     889 - 899
      W_FSTR59     900 - 910
      W_FSTR60     911 - 921
      W_FSTR61     922 - 932
      W_FSTR62     933 - 943
      W_FSTR63     944 - 954
      W_FSTR64     955 - 965
      W_FSTR65     966 - 976
      W_FSTR66     977 - 987
      W_FSTR67     988 - 998
      W_FSTR68     999 - 1009
      W_FSTR69    1010 - 1020
      W_FSTR70    1021 - 1031
      W_FSTR71    1032 - 1042
      W_FSTR72    1043 - 1053
      W_FSTR73    1054 - 1064
      W_FSTR74    1065 - 1075
      W_FSTR75    1076 - 1086
      W_FSTR76    1087 - 1097
      W_FSTR77    1098 - 1108
      W_FSTR78    1109 - 1119
      W_FSTR79    1120 - 1130
      W_FSTR80    1131 - 1141
      W_FSTR81    1142 - 1152
      W_FSTR82    1153 - 1163
      W_FSTR83    1164 - 1174
      W_FSTR84    1175 - 1185
      W_FSTR85    1186 - 1196
      W_FSTR86    1197 - 1207
      W_FSTR87    1208 - 1218
      W_FSTR88    1219 - 1229
      W_FSTR89    1230 - 1240
      W_FSTR90    1241 - 1251
      W_FSTR91    1252 - 1262
      W_FSTR92    1263 - 1273
      W_FSTR93    1274 - 1284
      W_FSTR94    1285 - 1295
      W_FSTR95    1296 - 1306
      W_FSTR96    1307 - 1317
      W_FSTR97    1318 - 1328
      W_FSTR98    1329 - 1339
      W_FSTR99    1340 - 1350
      W_FSTR100   1351 - 1361
;




   LABEL
      NACIONAL   = "Variable auxiliar para obtener promedios nacionales"
      ESCUELA    = "Identificador de la escuela"
      ID_ENT     = "Entidad federativa (identificador numrico)"
      NOM_ENT    = "Entidad federativa"
      ID_MOD     = "Estrato escolar o Modalidad educativa (identificador numrico)"
      MOD        = "Estrato escolar o Modalidad educativa"
      ESTRATO    = "Estrato de muestreo. Se construy con ENTIDAD, MODALIDAD. No es comn a todas las tablas pues en algunos casos se colapsaron registros"
      ENTEST     = "Estratos del diseo muestral con el que se estiman los parmetros y errores estndar (Entidad federativa-Modalidad)"
      ALUMNO     = "Identificador del alumno"
      ID_INSTR   = "Identificador del cuadernillo de examen"
      SEXO       = "Sexo del alumno"
      EDAD_AC    = "Edad en aos cumplidos (al momento de la aplicacin)"
      MES_NAC    = "Mes de nacimiento del alumno"
      EDAD       = "Edad del alumno al mes de mayo de 2014, en aos (al momento de la aplicacin). Incluye los meses cumplidos (decimales)"
      EDAD_ACC   = "Edad en aos cumplidos codificada (con recodificacin y colapsamiento de categoras de la variable EDAD_AC)"
      EDAD_N     = "Edad normativa. Supone el ingreso al primero de primaria con 6 aos cumplidos (o menos) al primero de septiembre"
      EDAD_ANT   = "Edad anticipada. Variable indicadora de los alumnos que ingresaron al primero de primaria con menos de 6 aos cumplidos al primero de septiembre"
      EDAD_EES   = "Extra edad severa. Variable indicadora de los alumnos que tienen dos aos o ms de retraso en el sistema escolar"
      W_ALU      = "Peso muestral o ponderador del alumno"
      DOCENTE    = "Identificador del docente que imparte clases al alumno"
      PCA_01     = "Reconoce el esfuerzo acadmico de sus compaeros."
      PCA_02     = "Aprecia los rasgos de quienes lo rodean."
      PCA_03     = "Distingue alimentos que contribuyen a su salud."
      PCA_04     = "Identifica acciones realizadas por los adultos que favorecen el cuidado de la salud."
      PCA_05     = "Reconoce la importancia de expresar ideas y sentimientos sin violencia."
      PCA_06     = "Reconoce la importancia de la autoridad en el cumlimiento de las reglas."
      PCA_07     = "Reconoce la importancia de convivir con personas con costumbres diferentes a las suyas."
      PCA_08     = "Valora la equidad de gnero."
      PCA_09     = "Reconoce la importancia de la imparcialidad al aplicar las normas o leyes."
      PCA_10     = "Reconoce las consecuencias de infringir la ley."
      PCA_11     = "Reconoce el papel de las autoridades en la aplicacin de las normas."
      PCA_12     = "Valora la pluralidad de intereses en la toma de decisiones democraticas."
      PCA_13     = "Comprende la importancia de denunciar o mediar frente a situaciones violentas."
      PCA_14     = "Comprende que el incumplimiento de los derechos de las personas es violencia."
      PCA_15     = "Reconoce estrategias para prevenir la violencia."
      PCA_16     = "Reconoce la importancia de la tolerancia en en la resolucin de conflictos."
      PCA_17     = "Identifica la nocin de organizarse."
      PCB_01     = "Respeta las caractersticas culturales de nias y nios."
      PCB_02     = "Aprecia que los rasgos compartidos le dan identidad."
      PCB_03     = "Distingue situaciones que violentan los derechos de las nias y los nios."
      PCB_04     = "Identifica actividades que promuven el cuidado de su salud."
      PCB_05     = "Valora la importancia de la escucha para la convivencia."
      PCB_06     = "Identifica una meta."
      PCB_07     = "Reconoce la importancia de aplicar las reglas a todos por igual."
      PCB_08     = "Reconoce acciones para enfrentar la discriminacin."
      PCB_09     = "Reconoce formas de consumo responsable de recursos naturales."
      PCB_10     = "Reconoce las consecuencias del incumplimiento de las normas."
      PCB_11     = "Valora establecer acuerdos por escrito."
      PCB_12     = "Comprende la importancia de difundir los derechos de las nias y los nios."
      PCB_13     = "Identifica las autoridades en su contexto inmediato."
      PCB_14     = "Reconoce las funciones de las autoridades."
      PCB_15     = "Reconoce leyes que sancionan a las autoridades."
      PCB_16     = "Comprende que las autoridades pueden ser injustas."
      PCB_17     = "Reconoce la importancia del respeto en la resolucin de conflictos."
      PCC_01     = "Respeta la manifestacin de las emociones."
      PCC_02     = "Valora su desempeo ante los dems."
      PCC_03     = "Aprecia acciones que contribuyen a la prevencin de accidentes."
      PCC_04     = "Comprende que la responsabilidad y el esfuerzo son fundamentales para lograr una meta."
      PCC_05     = "Critica actividades asignadas social e histricamente a mujeres y hombres."
      PCC_06     = "Distingue diferentes oportunidades entre mujeres y hombres."
      PCC_07     = "Identifica la importancia de reducir el consumo para el ambiente."
      PCC_08     = "Reconoce el papel de las autoridades en la aplicacin de las leyes."
      PCC_09     = "Valora su participacin en el establecimiento de acuerdos."
      PCC_10     = "Reconoce experiencias democrticas."
      PCC_11     = "Identifica personas e instituciones que protegen sus derechos."
      PCC_12     = "Comprende la importancia de informarse sobre sus derechos."
      PCC_13     = "Comprende que las autoridades pueden ser castigadas."
      PCC_14     = "Comprende la diversidad de intereses."
      PCC_15     = "Valora mecanismos democrticos para prevenir la violencia."
      PCC_16     = "Comprende la importancia de organizarse para lograr el bien comn."
      PCC_17     = "Comprende la importancia de participar en organizaciones que favorezcan la democracia."
      PCD_01     = "Reconoce estrategias de aprendizaje para apoyar a sus compaeros."
      PCD_02     = "Distingue actividades fsicas o recreativas que favorecen su salud."
      PCD_03     = "Reconoce la necesidad de expresar sus emociones."
      PCD_04     = "Identifica la importancia de la paciencia para satisfacer necesidades y deseos."
      PCD_05     = "Reconoce la importancia de establecer objetivos para aprender."
      PCD_06     = "Reconoce la importancia de las reglas para convivir."
      PCD_07     = "Aprecia el cumplimiento de las reglas para la convivencia."
      PCD_08     = "Valora la aplicacin de las reglas considerando las diferencias."
      PCD_09     = "Identifica tareas bsicas en el hogar."
      PCD_10     = "Reconoce la importancia de participar en los quehaceres del hogar."
      PCD_11     = "Reconoce los efectos del uso inadecuado de los recursos naturales."
      PCD_12     = "Valora su participacin en la elaboracin de normas en su contexto."
      PCD_13     = "Reconoce mecanismos para tomar decisiones democrticas."
      PCD_14     = "Comprende la necesidad de vigilar que los acuerdos se cumplan."
      PCD_15     = "Identifica situaciones cotidianas en las cuales se respetan sus derechos."
      PCD_16     = "Identifica el concepto de violencia."
      PCD_17     = "Reconoce acciones violentas."
      PCD_18     = "Reconoce la importancia de la solidaridad en en la resolucin de conflictos."
      PCE_01     = "Reconoce que cuenta con derechos que lo protegen."
      PCE_02     = "Aprecia acciones que contribuyen a su desarrollo fsico."
      PCE_03     = "Reconoce expresiones afectivas sin violencia."
      PCE_04     = "Distingue metas que puede alcanzar en su contexto."
      PCE_05     = "Valora que todas las personas satifagan sus necesidades bsicas."
      PCE_06     = "Reconoce que hay personas que no logran satisfacer sus necesidades bsicas."
      PCE_07     = "Reconoce efectos de la insatisfaccin de las necesidades bsicas."
      PCE_08     = "Distingue tratos discriminatorios."
      PCE_10     = "Identifica la importancia de reutilizar para el ambiente."
      PCE_11     = "Identifica la importancia de reciclar para el ambiente."
      PCE_12     = "Identifica al Poder Legislativo en la creacin de leyes."
      PCE_13     = "Reconoce que la exigencia del cumplimiento de acuerdos no debe ser violenta."
      PCE_14     = "Valora su participacin para el cumplimiento de sus derechos."
      PCE_15     = "Reconoce que las autoridades no estn por encima de las leyes."
      PCE_16     = "Reconoce que los conflictos son parte de la diversidad."
      PCE_17     = "Reconoce formas de participacin colectiva."
      PCF_01     = "Respeta las caractersticas fsicas de de nias y nios."
      PCF_02     = "Reconoce la prohibicin del trabajo infantil."
      PCF_03     = "Exige respeto a sus derechos."
      PCF_04     = "Aprecia acciones propias para el cuidado de su salud."
      PCF_05     = "Identificac el derecho a la libre expresin de ideas y sentimientos."
      PCF_06     = "Distingue entre necesidades y deseos."
      PCF_07     = "Reconoce la importancia de ser paciente ante las necesidades de los dems."
      PCF_08     = "Valora que las autoridades se apeguen a las reglas."
      PCF_10     = "Distingue entre normas y leyes."
      PCF_11     = "Reconoce la importancia de la participacin colectiva para establecer acuerdos."
      PCF_12     = "Valora la pluralidad de opiniones en la toma de decisiones democraticas."
      PCF_13     = "Reconoce sus derechos como nia o nio."
      PCF_14     = "Comprende en la dignidad humana el fundamento de la convivencia."
      PCF_15     = "Reconoce la imortancia de una tercera persona para solucionar conflictos."
      PCF_16     = "Identifica la toma de decisiones colectivas en la vida diaria."
      PCF_17     = "Distingue mecanismos para tomar decisiones colectivas."
      PV1FCE     = "Primer valor plausible de formacin cvica y tica"
      PV2FCE     = "Segundo valor plausible de formacin cvica y tica"
      PV3FCE     = "Tercer valor plausible de formacin cvica y tica"
      PV4FCE     = "Cuarto valor plausible de formacin cvica y tica"
      PV5FCE     = "Quinto valor plausible de formacin cvica y tica"
      FCENVL1    = "Nivel de logro en formacin cvica y tica. Asociado a PV1FCE. (Cuatro niveles)"
      FCENVL2    = "Nivel de logro en formacin cvica y tica. Asociado a PV2FCE. (Cuatro niveles)"
      FCENVL3    = "Nivel de logro en formacin cvica y tica. Asociado a PV3FCE. (Cuatro niveles)"
      FCENVL4    = "Nivel de logro en formacin cvica y tica. Asociado a PV4FCE. (Cuatro niveles)"
      FCENVL5    = "Nivel de logro en formacin cvica y tica. Asociado a PV5FCE. (Cuatro niveles)"
      FCENVBL1   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en formacin cvica y tica. Asociado a PV1FCE."
      FCENVBL2   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en formacin cvica y tica. Asociado a PV2FCE."
      FCENVBL3   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en formacin cvica y tica. Asociado a PV3FCE."
      FCENVBL4   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en formacin cvica y tica. Asociado a PV4FCE."
      FCENVBL5   = "Identifica si el alumno pertenece al menos al nivel bsico de logro en formacin cvica y tica. Asociado a PV5FCE."
      FCENVML1   = "Identifica si el alumno pertenece al menos al nivel medio de logro en formacin cvica y tica. Asociado a PV1FCE."
      FCENVML2   = "Identifica si el alumno pertenece al menos al nivel medio de logro en formacin cvica y tica. Asociado a PV2FCE."
      FCENVML3   = "Identifica si el alumno pertenece al menos al nivel medio de logro en formacin cvica y tica. Asociado a PV3FCE."
      FCENVML4   = "Identifica si el alumno pertenece al menos al nivel medio de logro en formacin cvica y tica. Asociado a PV4FCE."
      FCENVML5   = "Identifica si el alumno pertenece al menos al nivel medio de logro en formacin cvica y tica. Asociado a PV5FCE."
      WVARSTRR   = "Identificador del pseudoestrato (1 a 100) definido para el clculo de errores estndar con el mtodo de remuestreo BRR"
      W_FSTR1    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR2    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR3    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR4    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR5    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR6    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR7    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR8    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR9    = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR10   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR11   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR12   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR13   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR14   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR15   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR16   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR17   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR18   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR19   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR20   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR21   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR22   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR23   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR24   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR25   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR26   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR27   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR28   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR29   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR30   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR31   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR32   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR33   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR34   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR35   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR36   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR37   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR38   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR39   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR40   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR41   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR42   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR43   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR44   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR45   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR46   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR47   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR48   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR49   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR50   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR51   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR52   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR53   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR54   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR55   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR56   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR57   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR58   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR59   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR60   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR61   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR62   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR63   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR64   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR65   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR66   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR67   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR68   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR69   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR70   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR71   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR72   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR73   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR74   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR75   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR76   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR77   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR78   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR79   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR80   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR81   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR82   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR83   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR84   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR85   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR86   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR87   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR88   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR89   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR90   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR91   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR92   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR93   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR94   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR95   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR96   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR97   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR98   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR99   = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
      W_FSTR100  = "Pesos muestrales para el clculo de errores estndar (Mtodo BRR)"
;


   FORMAT
       NACIONAL    1.
       ESCUELA     4.
       ID_ENT      id_entF.
       NOM_ENT     $char19.
       ID_MOD      id_modF.
       MOD         $modF.
       ESTRATO     $char7.
       ENTEST      $entestF.
       ALUMNO      5.
       ID_INSTR    $char15.
       SEXO        sexoF.
       EDAD_AC     edad_acF.
       MES_NAC     mes_nacF.
       EDAD        edadF.
       EDAD_ACC    edadCF.
       EDAD_N      edadNF.
       EDAD_ANT    edadAF.
       EDAD_EES    edadEF.
       DOCENTE     docenF.
       PCA_01      reactF.
       PCA_02      reactF.
       PCA_03      reactF.
       PCA_04      reactF.
       PCA_05      reactF.
       PCA_06      reactF.
       PCA_07      reactF.
       PCA_08      reactF.
       PCA_09      reactF.
       PCA_10      reactF.
       PCA_11      reactF.
       PCA_12      reactF.
       PCA_13      reactF.
       PCA_14      reactF.
       PCA_15      reactF.
       PCA_16      reactF.
       PCA_17      reactF.
       PCB_01      reactF.
       PCB_02      reactF.
       PCB_03      reactF.
       PCB_04      reactF.
       PCB_05      reactF.
       PCB_06      reactF.
       PCB_07      reactF.
       PCB_08      reactF.
       PCB_09      reactF.
       PCB_10      reactF.
       PCB_11      reactF.
       PCB_12      reactF.
       PCB_13      reactF.
       PCB_14      reactF.
       PCB_15      reactF.
       PCB_16      reactF.
       PCB_17      reactF.
       PCC_01      reactF.
       PCC_02      reactF.
       PCC_03      reactF.
       PCC_04      reactF.
       PCC_05      reactF.
       PCC_06      reactF.
       PCC_07      reactF.
       PCC_08      reactF.
       PCC_09      reactF.
       PCC_10      reactF.
       PCC_11      reactF.
       PCC_12      reactF.
       PCC_13      reactF.
       PCC_14      reactF.
       PCC_15      reactF.
       PCC_16      reactF.
       PCC_17      reactF.
       PCD_01      reactF.
       PCD_02      reactF.
       PCD_03      reactF.
       PCD_04      reactF.
       PCD_05      reactF.
       PCD_06      reactF.
       PCD_07      reactF.
       PCD_08      reactF.
       PCD_09      reactF.
       PCD_10      reactF.
       PCD_11      reactF.
       PCD_12      reactF.
       PCD_13      reactF.
       PCD_14      reactF.
       PCD_15      reactF.
       PCD_16      reactF.
       PCD_17      reactF.
       PCD_18      reactF.
       PCE_01      reactF.
       PCE_02      reactF.
       PCE_03      reactF.
       PCE_04      reactF.
       PCE_05      reactF.
       PCE_06      reactF.
       PCE_07      reactF.
       PCE_08      reactF.
       PCE_10      reactF.
       PCE_11      reactF.
       PCE_12      reactF.
       PCE_13      reactF.
       PCE_14      reactF.
       PCE_15      reactF.
       PCE_16      reactF.
       PCE_17      reactF.
       PCF_01      reactF.
       PCF_02      reactF.
       PCF_03      reactF.
       PCF_04      reactF.
       PCF_05      reactF.
       PCF_06      reactF.
       PCF_07      reactF.
       PCF_08      reactF.
       PCF_10      reactF.
       PCF_11      reactF.
       PCF_12      reactF.
       PCF_13      reactF.
       PCF_14      reactF.
       PCF_15      reactF.
       PCF_16      reactF.
       PCF_17      reactF.
       FCENVL1     nvlF.
       FCENVL2     nvlF.
       FCENVL3     nvlF.
       FCENVL4     nvlF.
       FCENVL5     nvlF.
       FCENVBL1    nvblF.
       FCENVBL2    nvblF.
       FCENVBL3    nvblF.
       FCENVBL4    nvblF.
       FCENVBL5    nvblF.
       FCENVML1    nvmlF.
       FCENVML2    nvmlF.
       FCENVML3    nvmlF.
       FCENVML4    nvmlF.
       FCENVML5    nvmlF.
       wvarstrr    3.
   ;

/**************************************************************************
/*  Definicin de valores perdidos
/*   .N o N = No Administrado o no alcanzado.
/*   .M o M = Respuesta Mltiple.
/*   .S o S = Respuesta omitida (No contestado).
/*************************************************************************/
 IF  sexo = 8 THEN  sexo = .M;
 IF  edad_ac = 98 THEN  edad_ac = .M;
 IF  mes_nac = 98 THEN  mes_nac = .M;
 IF  entest = "999" THEN  entest = .S;
 IF  Docente = 99999 THEN  Docente = .S;


 ARRAY perdidos1(5)  sexo edad_acc edad_n edad_ant edad_ant;
 DO  i=1 TO 5;
       IF perdidos1{i}=9 THEN  perdidos1{i}= .S;
 END;

 ARRAY perdidos2(3)  edad edad_ac mes_nac;
 DO  i=1 TO 3;
       IF perdidos2{i}=99 THEN  perdidos2{i}= .S;
 END;


 ARRAY perdidos3(101)
              pca_01 pca_02 pca_03 pca_04 pca_05 pca_06 pca_07 pca_08 pca_09 pca_10 pca_11 pca_12 pca_13 pca_14 pca_15 pca_16 pca_17
              pcb_01 pcb_02 pcb_03 pcb_04 pcb_05 pcb_06 pcb_07 pcb_08 pcb_09 pcb_10 pcb_11 pcb_12 pcb_13 pcb_14 pcb_15 pcb_16 pcb_17
              pcc_01 pcc_02 pcc_03 pcc_04 pcc_05 pcc_06 pcc_07 pcc_08 pcc_09 pcc_10 pcc_11 pcc_12 pcc_13 pcc_14 pcc_15 pcc_16 pcc_17
              pcd_01 pcd_02 pcd_03 pcd_04 pcd_05 pcd_06 pcd_07 pcd_08 pcd_09 pcd_10 pcd_11 pcd_12 pcd_13 pcd_14 pcd_15 pcd_16 pcd_17
              pcd_18 pce_01 pce_02 pce_03 pce_04 pce_05 pce_06 pce_07 pce_08 pce_10 pce_11 pce_12 pce_13 pce_14 pce_15 pce_16 pce_17
              pcf_01 pcf_02 pcf_03 pcf_04 pcf_05 pcf_06 pcf_07 pcf_08 pcf_10 pcf_11 pcf_12 pcf_13 pcf_14 pcf_15 pcf_16 pcf_17;
 DO  i=1 TO 101;
        IF perdidos3{i} = 5   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 6   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 7   THEN  perdidos3{i} = .N;
        IF perdidos3{i} = 8   THEN  perdidos3{i} = .M;
        IF perdidos3{i} = 9   THEN  perdidos3{i} = .S;
 END;

 drop i;
RUN;


